import { ActivityStatus } from '../util/Types';
import { ActivityType } from '../util/Constants';
import BaseUser from './BaseUser';
import Client from './Client';
export default class ClientUser extends BaseUser {
    /**
     * Represents the user that is logged in to the client.
     *
     * @param {Client} client The client this user belongs to.
     * @param {any} data The data of this user.
     */
    constructor(client: Client, data: any);
    /**
     * Builds the ClientUser.
     *
     * @param {any} data The data of this user.
     * @returns {ClientUser} The ClientUser.
     */
    private build;
    /**
     * Updates the user's presence.
     *
     * @param {object} [options] The options to use when updating the status.
     * @param {ActivityStatus} [options.status='online'] The status to set.
     * @param {boolean} [options.afk=false] Whether or not the user is AFK.
     * @param {object} [options.activity=null] The activity to set.
     * @param {string} options.activity.name The name of the activity.
     * @param {ActivityType} options.activity.type The URL of the activity.
     * @returns {void} Voids once the packet is sent to Discord.
     */
    updatePresence(options?: {
        status?: ActivityStatus;
        afk?: boolean;
        activity?: {
            name: string;
            type: ActivityType;
        } | null;
    }): void;
    /**
     * Set the username of the user.
     *
     * @param {string} username The new username.
     * @returns {Promise<void>} Resolves once the username is set.
     */
    setName(name: string): Promise<void>;
}
