import Channel from './Channel';
import Guild from './Guild';
import Client from './Client';
import ChannelPermissionsBlock from './blocks/ChannelPermissionsBlock';
export default abstract class GuildChannel extends Channel {
    /**
     * The guild this channel belongs to.
     */
    guild: Guild;
    /**
     * The permission overwrites associated with this
     * channel.
     */
    permissions: ChannelPermissionsBlock;
    /**
     * A GuildChannel represents any channel on Discord
     * that is associated with a guild.
     *
     * @param {Client} client The client this channel belongs to.
     * @param {any} data The data of this channel.
     * @param {Guild} [guild] The guild this channel belongs to.
     */
    constructor(client: Client, data: any, guild?: Guild);
    /**
     * Set the overwrites of this channel.
     *
     * @param {{ id: string, type: 'role' | 'member' }[]} overwrites The overwrites to set.
     */
    protected setOverwrites(overwrite: {
        id: string;
        type: 'role' | 'member';
    }[]): Promise<void>;
    /**
     * Send a raw API request to modify this channel
     *
     * @param {any} data The data to send.
     * @param {string} [reason] The reason for this action.
     */
    abstract modify(data: any, reason?: string): Promise<GuildChannel>;
}
