"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Channel_1 = __importDefault(require("./Channel"));
const ChannelPermissionsBlock_1 = __importDefault(require("./blocks/ChannelPermissionsBlock"));
class GuildChannel extends Channel_1.default {
    /**
     * A GuildChannel represents any channel on Discord
     * that is associated with a guild.
     *
     * @param {Client} client The client this channel belongs to.
     * @param {any} data The data of this channel.
     * @param {Guild} [guild] The guild this channel belongs to.
     */
    constructor(client, data, guild) {
        super(client, data);
        /**
         * The guild this channel belongs to.
         */
        this.guild = null;
        /**
         * The permission overwrites associated with this
         * channel.
         */
        this.permissions = null;
        this.guild = guild ?? client.guilds.cache.get(data.guild_id);
        this.permissions = new ChannelPermissionsBlock_1.default(client, this, data.permission_overwrites);
    }
    /**
     * Set the overwrites of this channel.
     *
     * @param {{ id: string, type: 'role' | 'member' }[]} overwrites The overwrites to set.
     */
    async setOverwrites(overwrite) {
    }
}
exports.default = GuildChannel;
