import Client from './Client';
import User from './User';
export default class PartialUser {
    client: Client;
    readonly id: string;
    username: string;
    discriminator: string;
    tag: string;
    /**
     * **Warning:** Only the `id` property is guaranteed to be
     * set. Run the `fetch()` method to retrieve the entirety
     * of the User from the Discord API. If the username and/or
     * discriminator are not provided, they will be set to
     * `Unknown` and `0000` respectively.
     *
     * @param {Client} client The client this user belongs to.
     * @param {any} data The data of this user.
     */
    constructor(client: Client, data: any);
    /**
     * Build the data of this user.
     *
     * @param {any} data The data of this user.
     * @returns {PartialUser} This user.
     */
    private build;
    /**
     * Fetch (and resolve) this PartialUser into a User.
     *
     * @param {Object} [options] The options to use when fetching the user.
     * @param {boolean} [options.shouldCache=true] Whether or not to cache the result.
     * @param {boolean} [options.bypassCache=true] Whether or not to bypass the cache.
     * @returns {Promise<User>} A promise that resolves with user.
     * @public
     */
    fetch(options?: {
        shouldCache?: boolean | undefined;
        bypassCache?: boolean | undefined;
    }): Promise<User>;
    /**
     * Convert this User into a mention (string).
     *
     * @returns {string} A string that mentions this user.
     */
    toString(): string;
    /**
     * Whether or not this instance is a full or partial
     * user. A partial user is a user that is only
     * guaranteed to have `id` set on them.
     *
     * @returns {boolean} `true` if this is a partial user, `false` otherwise.
     */
    isPartial(): boolean;
}
