import Client from './Client';
import PermissionsBlock from './blocks/PermissionsBlock';
export default class PermissionOverwrite {
    /**
     * The client this overwrite belongs to.
     */
    client: Client;
    /**
     * The allowed permissions.
     */
    allow: PermissionsBlock;
    /**
     * The denied permissions.
     */
    deny: PermissionsBlock;
    /**
     * A permission overwrite represents a user or role
     * overwrite for a channel.
     *
     * @param {Client} client The client this overwrite belongs to.
     * @param {number} allow The allowed permissions.
     * @param {number} deny The denied permissions.
     */
    constructor(client: Client, allow?: number, deny?: number);
    /**
     * Grant the specified permissions.
     *
     * @param {number} flags The flags to grant.
     * @returns {PermissionOverwrite} The permission overwrite.
     */
    grant(...flags: number[]): PermissionOverwrite;
    /**
     * Revoke the specified permissions.
     *
     * @param {number} flags The flags to revoke.
     * @returns {PermissionOverwrite} The permission overwrite.
     */
    revoke(...flags: number[]): PermissionOverwrite;
}
