"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const PermissionsBlock_1 = __importDefault(require("./blocks/PermissionsBlock"));
class PermissionOverwrite {
    /**
     * A permission overwrite represents a user or role
     * overwrite for a channel.
     *
     * @param {Client} client The client this overwrite belongs to.
     * @param {number} allow The allowed permissions.
     * @param {number} deny The denied permissions.
     */
    constructor(client, allow = 0, deny = 0) {
        /**
         * The client this overwrite belongs to.
         */
        this.client = null;
        /**
         * The allowed permissions.
         */
        this.allow = null;
        /**
         * The denied permissions.
         */
        this.deny = null;
        this.client = client;
        this.allow = new PermissionsBlock_1.default(client, allow);
        this.deny = new PermissionsBlock_1.default(client, deny);
    }
    /**
     * Grant the specified permissions.
     *
     * @param {number} flags The flags to grant.
     * @returns {PermissionOverwrite} The permission overwrite.
     */
    grant(...flags) {
        for (let i = 0; i < flags.length; ++i) {
            if (this.deny.has(flags[i]))
                this.deny.remove(flags[i]);
            else
                this.allow.add(flags[i]);
        }
        return this;
    }
    /**
     * Revoke the specified permissions.
     *
     * @param {number} flags The flags to revoke.
     * @returns {PermissionOverwrite} The permission overwrite.
     */
    revoke(...flags) {
        for (let i = 0; i < flags.length; ++i) {
            if (this.allow.has(flags[i]))
                this.allow.remove(flags[i]);
            else
                this.deny.add(flags[i]);
        }
        return this;
    }
}
exports.default = PermissionOverwrite;
