import BitsBlock from './blocks/BitsBlock';
export default class Permissions extends BitsBlock {
    /**
     * The permission flags available.
     */
    static FLAGS: {
        /**
         * Create invite links.
         */
        CREATE_INSTANT_INVITE: number;
        /**
         * Kick other members.
         */
        KICK_MEMBERS: number;
        /**
         * Ban other members.
         */
        BAN_MEMBERS: number;
        /**
         * ⚠️ **No bot truly needs the Administrator
         * permission** with the exception of some
         * moderation and anti-abuse type bots. You should
         * consider whether or not a group of less
         * priviliged permissions would suffice for your
         * use case. Requesting the Administrator
         * permission just puts your users at risk and can
         * lead to unneeded privacy concerns.
         */
        ADMINISTRATOR: number;
        /**
         * Manage channels in this guild.
         */
        MANAGE_CHANNELS: number;
        /**
         * Manage the guild's settings.
         */
        MANAGE_GUILD: number;
        /**
         * Add reactions to messages. Users without this
         * permission will still be able to react to
         * already-added reactions.
         */
        ADD_REACTIONS: number;
        /**
         * View the guild's audit log.
         */
        VIEW_AUDIT_LOG: number;
        /**
         * Grants the ability to speak in priority mode.
         * Whilst a member is speaking in priority mode,
         * everyone else's volume is decreased until the
         * priority member stops speaking.
         */
        PRIORITY_SPEAKER: number;
        /**
         * Stream games and video to the channel.
         */
        STREAM: number;
        /**
         * View the guild's channels.
         */
        VIEW_CHANNEL: number;
        /**
         * Send messages in the guild's channels.
         */
        SEND_MESSAGES: number;
        /**
         * Send text-to-speach messages in the guild's
         * channels.
         */
        SEND_TTS_MESSAGES: number;
        /**
         * Delete and/or report messages in the guild's
         * channels.
         */
        MANAGE_MESSAGES: number;
        /**
         * Embed links and GIFs in messages.
         */
        EMBED_LINKS: number;
        /**
         * Attach files to messages.
         */
        ATTACH_FILES: number;
        /**
         * Read messages sent before launching the client.
         */
        READ_MESSAGE_HISTORY: number;
        /**
         * Mention @everyone, @here, and all roles.
         */
        MENTION_EVERYONE: number;
        /**
         * Use emojis from other guilds.
         */
        USE_EXTERNAL_EMOJIS: number;
        /**
         * View the guild's insights and stats.
         */
        VIEW_GUILD_INSIGHTS: number;
        /**
         * Connect to voice channels.
         */
        CONNECT: number;
        /**
         * Speak in voice channels.
         */
        SPEAK: number;
        /**
         * Mute members in voice channels.
         */
        MUTE_MEMBERS: number;
        /**
         * Deafen members in voice channels.
         */
        DEAFEN_MEMBERS: number;
        /**
         * Move members between voice channels and
         * disconnect them completely.
         */
        MOVE_MEMBERS: number;
        /**
         * Use voice-activity-detection in voice channels.
         * Removes the need of push-to-talk.
         */
        USE_VAD: number;
        /**
         * Change their own nickname.
         */
        CHANGE_NICKNAME: number;
        /**
         * Change the nicknames of other members.
         */
        MANAGE_NICKNAMES: number;
        /**
         * Manage the guild's roles, including creating,
         * editing, and deleting the roles, and modify the
         * roles of themselves and other members.
         */
        MANAGE_ROLES: number;
        /**
         * Create, modify, and delete webhooks, and follow
         * external text channels.
         */
        MANAGE_WEBHOOKS: number;
        /**
         * Create, modify, and delete emojis and stickers.
         */
        MANAGE_EMOJIS_AND_STICKERS: number;
        /**
         * Use slash and application commands.
         */
        USE_APPLICATION_COMMANDS: number;
        /**
         * Request to speak in stage channels.
         */
        REQUEST_TO_SPEAK: number;
        /**
         * Manage guild events.
         */
        MANAGE_EVENTS: number;
        /**
         * Delete and modify threads.
         */
        MANAGE_THREADS: number;
        /**
         * Create public threads.
         */
        CREATE_PUBLIC_THREADS: number;
        /**
         * Create private threads.
         */
        CREATE_PRIVATE_THREADS: number;
        /**
         * Use stickers from other guilds.
         */
        USE_EXTERNAL_STICKERS: number;
        /**
         * Send messages in threads.
         */
        SEND_MESSAGES_IN_THREADS: number;
        /**
         * Start embedded activities and applications.
         */
        START_EMBEDDED_ACTIVITIES: number;
    };
    /**
     * Permissions objects store permission data.
     *
     * @param {number} flags The permission flags.
     */
    constructor(...flags: number[]);
    /**
     * Check whether or not the permission flags exist on
     * this Permissions object, whilst taking the
     * administrator permission into account. If you want
     * to ignore the administrator permission, use the
     * `has` method instead.
     *
     * @param {number} flag The permission flag to check for.
     * @returns {boolean} Whether or not the permission flag exists.
     */
    hasPermission(flag: number): boolean;
}
