export default class BitsBlock {
    /**
     * The flags of the bitfield.
     */
    flags: number;
    /**
     * A BitsBlock stores bitfield data provided by Discord.
     *
     * @param {...number[]} flags The flags to set.
     */
    constructor(...flags: number[]);
    /**
     * Adds a flag (bit) to the block.
     *
     * @param {...number[]} flags The flags to add.
     * @returns {BitsBlock} The updated block.
     */
    add(...flags: number[]): BitsBlock;
    /**
     * Sets the flags of the block.
     *
     * @param {...number[]} flags The flags to set.
     * @returns {BitsBlock} The updated block.
     */
    set(flags: number): BitsBlock;
    /**
     * Removes a flag (bit) from the block.
     *
     * @param {...number[]} flags The flags to remove.
     * @returns {BitsBlock} The updated block.
     */
    remove(...flags: number[]): BitsBlock;
    /**
     * Check if a flag (bit) is in the block.
     *
     * @param {number} flag The flag to check.
     * @returns {boolean} The result.
     */
    has(flag: number): boolean;
    /**
     * Check if the block is empty.
     *
     * @returns {boolean} `true` if the block is empty, `false` otherwise.
     */
    isEmpty(): boolean;
    /**
     * Returns a new BitsBlock with the flags of this
     * block.
     *
     * @returns {BitsBlock} The new block.
     */
    clone(): BitsBlock;
}
