"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const RolePermissionOverwrite_1 = __importDefault(require("../RolePermissionOverwrite"));
const User_1 = __importDefault(require("../User"));
const UserPermissionOverwrite_1 = __importDefault(require("../UserPermissionOverwrite"));
class ChannelPermissionsBlock {
    /**
     * A ChannelPermissionsBlock stores data about channel
     * permissions.
     *
     * @param {Client} client The client instance.
     * @param {GuildChannel} channel The channel this permissions block is for.
     * @param {any[]} overwrites The data to parse.
     */
    constructor(client, channel, overwrites) {
        /**
         * The client that initiliazed the block.
         */
        this.client = null;
        /**
         * The channel this permissions block is for.
         */
        this.channel = null;
        /**
         * The list of permission overwrites.
         */
        this.overwrites = [];
        this.client = client;
        this.channel = channel;
        let roles = overwrites.filter(o => o.type === 0);
        let users = overwrites.filter(o => o.type === 1);
        for (let i = 0; i < roles.length; ++i) {
            let role = this.channel.guild.roles.cache.get(roles[i]);
            this.overwrites.push(new RolePermissionOverwrite_1.default(this.client, role, roles[i].allow, roles[i].deny));
        }
        for (let i = 0; i < users.length; ++i) {
            let user = User_1.default['retrieveOrBuildPartial'](this.client, { id: users[i] });
            this.overwrites.push(new UserPermissionOverwrite_1.default(this.client, user, users[i].allow, users[i].deny));
        }
    }
}
exports.default = ChannelPermissionsBlock;
