"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Guild_1 = __importDefault(require("../Guild"));
const HTTPGuild_1 = __importDefault(require("../http/HTTPGuild"));
const CachedBlock_1 = __importDefault(require("./CachedBlock"));
const CCache_1 = __importDefault(require("../cache/CCache"));
class GuildBlock extends CachedBlock_1.default {
    /**
     * A GuildBlock stores guild data.
     *
     * @param {Client} client The client instance.
     * @param {any} [options] The Cache options.
     */
    constructor(client, options) {
        super(client, new CCache_1.default(client, options));
    }
    /**
     * Fetches a guild from the cache or Discord if it is
     * not already cached.
     *
     * @param {GuildResolvable | Object} options The options to use.
     * @returns {Promise<Guild>} The guild.
     */
    async fetch(options) {
        if (typeof options === 'string') {
            options = {
                guild: options,
                shouldCache: true,
                bypassCache: false,
            };
        }
        else if (options instanceof Guild_1.default) {
            options = {
                guild: options.id,
                shouldCache: true,
                bypassCache: false,
            };
        }
        else {
            options.shouldCache ?? (options.shouldCache = true);
            options.bypassCache ?? (options.bypassCache = false);
            if (options.guild instanceof Guild_1.default)
                options.guild = options.guild.id;
            else
                options.guild = options.guild;
        }
        if (!options.bypassCache) {
            const cached = this.cache.get(options.guild);
            if (cached) {
                return cached;
            }
        }
        let guild = await HTTPGuild_1.default.get(this.client, options.guild);
        guild = new Guild_1.default(this.client, guild);
        if (options.shouldCache)
            this.cache.set(guild.id, guild);
        return guild;
    }
}
exports.default = GuildBlock;
