import Client from '../Client';
import CachedBlock from './CachedBlock';
import { UserResolvable } from '../../util/Types';
import GuildMember from '../GuildMember';
import Guild from '../Guild';
export default class GuildMemberBlock extends CachedBlock {
    /**
     * The guild that the block is for.
     */
    guild: Guild;
    /**
     * A GuildMemberBlock stores guild member data.
     *
     * @param {Client} client The client instance.
     * @param {Guild} guild The guild that the block is for.
     * @param {any} [options] The Cache options.
     */
    constructor(client: Client, guild: Guild, options?: any);
    /**
     * Fetch a guild member from the cache or the Discord\
     * API if it is not in the cache.
     *
     * @param {string} userId The user's ID.
     * @param {object} [options] The options to pass to the API.
     * @param {boolean} [options.shouldCache=true] Whether or not to cache the member.
     * @param {boolean} [options.bypassCache=false] Whether to force the request to the API, bypassing the cache.
     * @returns {Promise<GuildMember>} The guild member.
     */
    fetch(userId: string, options?: {
        shouldCache?: boolean;
        bypassCache?: boolean;
    }): Promise<GuildMember>;
    /**
     * Resolve a user to a GuildMember. Returns null if the
     * member is not cached.
     *
     * @param {UserResolvable} user The member to resolve.
     * @param {any} [def] The default value to return if the member is not cached.
     * @returns {GuildMember | null} The member. `null` if the member is not cached.
     */
    resolve(user: UserResolvable, def?: any): GuildMember | null;
}
