import Client from '../Client';
import CachedBlock from './CachedBlock';
import ClientUser from '../ClientUser';
import User from '../User';
import { UserResolvable } from '../../util/Types';
export default class UserBlock extends CachedBlock {
    /**
     * A UserBlock stores user data.
     *
     * @param {Client} client The client instance.
     * @param {any} [options] The Cache options.
     */
    constructor(client: Client, options?: any);
    /**
     * Fetches this Client's user.
     *
     * @returns {Promise<User>} The Client's user.
     */
    fetchMe(): Promise<ClientUser>;
    /**
     * Fetches a user from the Cache or the Discord API if
     * the user is not cached.
     *
     * @param {string} userId The ID of the user to fetch.
     * @param {object} [options] The options to use.
     * @param {boolean} [options.shouldCache=true] Whether to cache the user.
     * @param {boolean} [options.bypassCache=false] Whether to bypass the cache and fetch the user directly from the API.
     * @returns {Promise<User>} The user.
     */
    fetch(userId: string, options?: {
        shouldCache?: boolean;
        bypassCache?: boolean;
    }): Promise<User>;
    /**
     * Resolves a UserResolvable to a user if the user is
     * in the cache.
     *
     * @param {UserResolvable} user The user to resolve.
     * @param {any} [def] The default value to build the user if the user is not cached.
     * @returns {User | null} The user. `null` if the user is not cached.
     */
    resolve(user: UserResolvable, def?: any): User | null;
}
