/// <reference types="node" />
export default class MessageAttachment {
    /**
     * The ID of this attachment. Not present if the
     * attachment is yet to be uploaded to Discord.
     */
    id: string | null;
    /**
     * The buffer containing this attachment's data.
     */
    buffer: Buffer | null;
    /**
     * The Discord CDN URL to this attachment. Not present
     * if the attachment is yet to be uploaded to Discord.
     */
    url: string | null;
    /**
     * The Discord proxy URL to this attachment. Not
     * present if the attachment is yet to be uploaded to
     * Discord.
     */
    proxyUrl: string | null;
    /**
     * The filename of this attachment. Can be used to
     * represent this attachment in embededs. For example,
     * if the filename is `image.png`, then the attachment
     * URL would be `attachment://image.png`.
     */
    filename: string;
    /**
     * Creates a new attachment. Does not upload the
     * attachment to Discord.
     *
     * @param {Buffer | string | null} file The file to upload. If a string, it is assumed to be the path to the file (which Birb.JS shall read and turn into a buffer). Rarely should be set to `null`.
     * @param {string} filename The filename of the attachment. Rarely should be set to `null`.
     * @param {string} [id] The ID of the attachment. Set by Birb.JS internally.
     * @param {string} [url] The Discord CDN URL of the attachment. Set by Birb.JS internally.
     * @param {string} [proxyUrl] The Discord proxy URL of the attachment. Set by Birb.JS internally.
     */
    constructor(file?: Buffer | string | null, filename?: string | null, id?: string, url?: string, proxyUrl?: string);
    /**
     * Gets the attachment's data as a Buffer.
     *
     * @returns {Buffer | null} The attachment's data as a Buffer. `null` if the attachment was received from Discord.
     */
    getBuffer(): Buffer | null;
    /**
     * An internal method that creates an array of
     * MessageAttachment objects from an array of raw API
     * attachments. You probably don't need to use this.
     *
     * @param {attachments[] | null} attachments The raw API attachment data.
     * @returns {MessageAttachment[]} An array of MessageAttachment objects.
     */
    private static fromApiMessage;
}
