import EmbedChild from './EmbedChild';
export default class EmbedAuthor extends EmbedChild {
    /**
     * The name of the author.
     */
    name: string;
    url?: string;
    iconUrl?: string;
    /**
     * An EmbedAuthor stores data on the author field of
     * MessageEmbeds.
     *
     * @param {string} name The name of the author.
     * @param {string} [url] The URL of the author.
     * @param {string} [iconUrl] A publicly-accessible URL to an image to use as the author's icon.
     */
    constructor(name: string, url?: string, iconUrl?: string);
    /**
     * Set the name of the author.
     *
     * @param {string} name The name of the author.
     * @returns {EmbedAuthor} The updated EmbedAuthor.
     */
    setName(name: string): EmbedAuthor;
    /**
     * Set the URL of the author.
     *
     * @param {string | undefined} url The URL of the author. Pass through no arguments to remove the URL.
     * @returns {EmbedAuthor} The updated EmbedAuthor.
     */
    setUrl(url?: string): EmbedAuthor;
    /**
     * Set the icon URL of the author.
     *
     * @param {string | undefined} iconUrl A publicly-accessible URL to an image to use as the author's icon. Pass through no arguments to remove the icon.
     * @returns {EmbedAuthor} The updated EmbedAuthor.
     */
    setIconUrl(iconUrl?: string): EmbedAuthor;
    /**
     * Remove the author's URL.
     *
     * @returns {EmbedAuthor} The updated EmbedAuthor.
     */
    removeUrl(): EmbedAuthor;
    /**
     * Remove the author's icon.
     *
     * @returns {EmbedAuthor} The updated EmbedAuthor.
     */
    removeIcon(): EmbedAuthor;
    /**
     * Format this class into an API-acceptable object.
     *
     * @returns {any} The formatted object.
     */
    format(): any;
}
