import EmbedChild from './EmbedChild';
export default class EmbedField extends EmbedChild {
    /**
     * The name of the field.
     */
    name: string;
    /**
     * The value of the field.
     */
    value: string;
    /**
     * Whether or not this field is inline.
     */
    inline: boolean;
    /**
     * An EmbedField stores data on a field of a
     * MessageEmbed.
     *
     * @param {string} name The name of the field.
     * @param {string} value The value of the field.
     * @param {boolean} [inline=false] Whether or not this field is inline.
     */
    constructor(name: string, value: string, inline?: boolean);
    /**
     * Set the name of the field.
     *
     * @param {string} name The name of the field.
     * @returns {EmbedField} The updated EmbedField.
     */
    setName(name: string): EmbedField;
    /**
     * Set the value of the field.
     *
     * @param {string} value The value of the field.
     * @returns {EmbedField} The updated EmbedField.
     */
    setValue(value: string): EmbedField;
    /**
     * Set whether or not this field is inline.
     *
     * @param {boolean} inline Whether or not this field is inline.
     * @returns {EmbedField} The updated EmbedField.
     */
    setInline(inline: boolean): EmbedField;
    /**
     * Format this class into an API-acceptable object.
     *
     * @returns {any} The formatted object.
     */
    format(): any;
}
