"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const EmbedChild_1 = __importDefault(require("./EmbedChild"));
class EmbedField extends EmbedChild_1.default {
    /**
     * An EmbedField stores data on a field of a
     * MessageEmbed.
     *
     * @param {string} name The name of the field.
     * @param {string} value The value of the field.
     * @param {boolean} [inline=false] Whether or not this field is inline.
     */
    constructor(name, value, inline) {
        super();
        /**
         * The name of the field.
         */
        this.name = null;
        /**
         * The value of the field.
         */
        this.value = null;
        /**
         * Whether or not this field is inline.
         */
        this.inline = false;
        this.name = name;
        this.value = value;
        this.inline = inline ?? false;
    }
    /**
     * Set the name of the field.
     *
     * @param {string} name The name of the field.
     * @returns {EmbedField} The updated EmbedField.
     */
    setName(name) {
        this.name = name;
        return this;
    }
    /**
     * Set the value of the field.
     *
     * @param {string} value The value of the field.
     * @returns {EmbedField} The updated EmbedField.
     */
    setValue(value) {
        this.value = value;
        return this;
    }
    /**
     * Set whether or not this field is inline.
     *
     * @param {boolean} inline Whether or not this field is inline.
     * @returns {EmbedField} The updated EmbedField.
     */
    setInline(inline) {
        this.inline = inline;
        return this;
    }
    /**
     * Format this class into an API-acceptable object.
     *
     * @returns {any} The formatted object.
     */
    format() {
        return {
            name: this.name,
            value: this.value,
            inline: this.inline
        };
    }
}
exports.default = EmbedField;
