import EmbedChild from './EmbedChild';
export default class EmbedFooter extends EmbedChild {
    /**
     * The text displayed at the bottom of the embed.
     */
    text: string;
    /**
     * The URL of the icon displayed at the bottom of the
     * embed.
     */
    iconUrl?: string;
    /**
     * An EmbedFooter stores data on the footer field of
     * a MessageEmbed.
     *
     * @param {string} text The text displayed at the bottom of the embed.
     * @param {string} [iconUrl] A publicly-accessible URL to an image to use as the footer's icon.
     */
    constructor(text: string, iconUrl?: string);
    /**
     * Set the text displayed at the bottom of the embed.
     *
     * @param {string} text The text displayed at the bottom of the embed.
     * @returns {EmbedFooter} The updated EmbedFooter.
     */
    setText(text: string): EmbedFooter;
    /**
     * Set the URL of the icon displayed at the bottom of the
     * embed.
     *
     * @param {string | undefined} url The URL of the icon. Pass through no arguments to remove the URL.
     * @returns {EmbedFooter} The updated EmbedFooter.
     */
    setIconUrl(iconUrl?: string): EmbedFooter;
    /**
     * Remove the the icon displayed at the bottom of the
     * embed.
     *
     * @returns {EmbedFooter} The updated EmbedFooter.
     */
    removeIcon(): EmbedFooter;
    /**
     * Format this class into an API-acceptable object.
     *
     * @returns {any} The formatted object.
     */
    format(): any;
}
