"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const EmbedChild_1 = __importDefault(require("./EmbedChild"));
class EmbedFooter extends EmbedChild_1.default {
    /**
     * An EmbedFooter stores data on the footer field of
     * a MessageEmbed.
     *
     * @param {string} text The text displayed at the bottom of the embed.
     * @param {string} [iconUrl] A publicly-accessible URL to an image to use as the footer's icon.
     */
    constructor(text, iconUrl) {
        super();
        /**
         * The text displayed at the bottom of the embed.
         */
        this.text = null;
        this.text = text;
        this.iconUrl = iconUrl ?? undefined;
    }
    /**
     * Set the text displayed at the bottom of the embed.
     *
     * @param {string} text The text displayed at the bottom of the embed.
     * @returns {EmbedFooter} The updated EmbedFooter.
     */
    setText(text) {
        this.text = text;
        return this;
    }
    /**
     * Set the URL of the icon displayed at the bottom of the
     * embed.
     *
     * @param {string | undefined} url The URL of the icon. Pass through no arguments to remove the URL.
     * @returns {EmbedFooter} The updated EmbedFooter.
     */
    setIconUrl(iconUrl) {
        this.iconUrl = iconUrl;
        return this;
    }
    /**
     * Remove the the icon displayed at the bottom of the
     * embed.
     *
     * @returns {EmbedFooter} The updated EmbedFooter.
     */
    removeIcon() {
        this.iconUrl = undefined;
        return this;
    }
    /**
     * Format this class into an API-acceptable object.
     *
     * @returns {any} The formatted object.
     */
    format() {
        return {
            text: this.text,
            icon_url: this.iconUrl
        };
    }
}
exports.default = EmbedFooter;
