import EmbedChild from './EmbedChild';
export default class EmbedMedia extends EmbedChild {
    /**
     * The URL of the media.
     */
    url: string;
    /**
     * The height of the media.
     */
    height?: number;
    /**
     * The width of the media.
     */
    width?: number;
    /**
     * An EmbedMedia stores data on a media or attachment
     * field of a MessageEmbed.
     *
     * @param {string} url The URL of the media. If refrences an attachment, prefix with `attachment://` followed by the attachment's filename.
     * @param {number} [height] The height of the media.
     * @param {number} [width] The width of the media.
     */
    constructor(url: string, height?: number, width?: number);
    /**
     * Set the URL of the media.
     *
     * @param {string} url The URL of the media. If refrences an attachment, prefix with `attachment://` followed by the attachment's filename.
     * @returns {EmbedMedia} The updated EmbedMedia.
     */
    setUrl(url: string): EmbedMedia;
    /**
     * Set the height of the media.
     *
     * @param {number | undefined} height The height of the media. Pass through no arguments to remove the height.
     * @returns {EmbedMedia} The updated EmbedMedia.
     */
    setHeight(height?: number): EmbedMedia;
    /**
     * Set the width of the media.
     *
     * @param {number | undefined} width The width of the media. Pass through no arguments to remove the width.
     * @returns {EmbedMedia} The updated EmbedMedia.
     */
    setWidth(width?: number): EmbedMedia;
    /**
     * Remove the height of the media.
     *
     * @returns {EmbedMedia} The updated EmbedMedia.
     */
    removeHeight(): EmbedMedia;
    /**
     * Remove the width of the media.
     *
     * @returns {EmbedMedia} The updated EmbedMedia.
     */
    removeWidth(): EmbedMedia;
    /**
     * Format this class into an API-acceptable object.
     *
     * @returns {any} The formatted object.
     */
    format(): any;
}
