"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const EmbedChild_1 = __importDefault(require("./EmbedChild"));
class EmbedMedia extends EmbedChild_1.default {
    /**
     * An EmbedMedia stores data on a media or attachment
     * field of a MessageEmbed.
     *
     * @param {string} url The URL of the media. If refrences an attachment, prefix with `attachment://` followed by the attachment's filename.
     * @param {number} [height] The height of the media.
     * @param {number} [width] The width of the media.
     */
    constructor(url, height, width) {
        super();
        /**
         * The URL of the media.
         */
        this.url = null;
        this.url = url;
        this.height = height;
        this.width = width;
    }
    /**
     * Set the URL of the media.
     *
     * @param {string} url The URL of the media. If refrences an attachment, prefix with `attachment://` followed by the attachment's filename.
     * @returns {EmbedMedia} The updated EmbedMedia.
     */
    setUrl(url) {
        this.url = url;
        return this;
    }
    /**
     * Set the height of the media.
     *
     * @param {number | undefined} height The height of the media. Pass through no arguments to remove the height.
     * @returns {EmbedMedia} The updated EmbedMedia.
     */
    setHeight(height) {
        this.height = height;
        return this;
    }
    /**
     * Set the width of the media.
     *
     * @param {number | undefined} width The width of the media. Pass through no arguments to remove the width.
     * @returns {EmbedMedia} The updated EmbedMedia.
     */
    setWidth(width) {
        this.width = width;
        return this;
    }
    /**
     * Remove the height of the media.
     *
     * @returns {EmbedMedia} The updated EmbedMedia.
     */
    removeHeight() {
        this.height = undefined;
        return this;
    }
    /**
     * Remove the width of the media.
     *
     * @returns {EmbedMedia} The updated EmbedMedia.
     */
    removeWidth() {
        this.width = undefined;
        return this;
    }
    /**
     * Format this class into an API-acceptable object.
     *
     * @returns {any} The formatted object.
     */
    format() {
        return {
            url: this.url,
            height: this.height,
            width: this.width
        };
    }
}
exports.default = EmbedMedia;
