"use strict";
/*
 * Copyright (c) 2021, knokbak and contributors.
 *
 * The Birb.JS Project: https://birb.js.org
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebhookTypes = exports.VisibilityTypes = exports.UserFlags = exports.StickerFormatTypes = exports.StickerTypes = exports.MessageFlags = exports.SystemMessageTypes = exports.MessageTypes = exports.ActivityType = exports.StageInstancePrivacyLevel = exports.InviteTargetTypes = exports.GuildScheduledEventsEntityTypes = exports.GuildScheduledEventsPrivacyLevel = exports.PremiumTier = exports.NSFWLevel = exports.ExplicitContentFilterLevel = exports.MFALevel = exports.VerificationLevel = exports.NotificationLevel = exports.SystemChannelFlags = exports.ChannelTypes = exports.GatewayCloseCode = exports.PacketOperation = exports.Status = exports.Intents = void 0;
/*
 *  API Constants
 *  These will be used for API connections
 */
// Client Intents
/**
 * The available Intents.
 */
var Intents;
(function (Intents) {
    Intents[Intents["GUILDS"] = 1] = "GUILDS";
    Intents[Intents["GUILD_MEMBERS"] = 2] = "GUILD_MEMBERS";
    Intents[Intents["GUILD_BANS"] = 4] = "GUILD_BANS";
    Intents[Intents["GUILD_EMOJIS_AND_STICKERS"] = 8] = "GUILD_EMOJIS_AND_STICKERS";
    Intents[Intents["GUILD_INTEGRATIONS"] = 16] = "GUILD_INTEGRATIONS";
    Intents[Intents["GUILD_WEBHOOKS"] = 32] = "GUILD_WEBHOOKS";
    Intents[Intents["GUILD_INVITES"] = 64] = "GUILD_INVITES";
    Intents[Intents["GUILD_VOICE_STATES"] = 128] = "GUILD_VOICE_STATES";
    Intents[Intents["GUILD_PRESENCES"] = 256] = "GUILD_PRESENCES";
    Intents[Intents["GUILD_MESSAGES"] = 512] = "GUILD_MESSAGES";
    Intents[Intents["GUILD_MESSAGE_REACTIONS"] = 1024] = "GUILD_MESSAGE_REACTIONS";
    Intents[Intents["GUILD_MESSAGE_TYPING"] = 2048] = "GUILD_MESSAGE_TYPING";
    Intents[Intents["DIRECT_MESSAGES"] = 4096] = "DIRECT_MESSAGES";
    Intents[Intents["DIRECT_MESSAGE_REACTIONS"] = 8192] = "DIRECT_MESSAGE_REACTIONS";
    Intents[Intents["DIRECT_MESSAGE_TYPING"] = 16384] = "DIRECT_MESSAGE_TYPING";
    Intents[Intents["GUILD_SCHEDULED_EVENTS"] = 65536] = "GUILD_SCHEDULED_EVENTS";
    Intents[Intents["NOT_PRIVILEGED"] = 98045] = "NOT_PRIVILEGED";
    Intents[Intents["ALL"] = 98303] = "ALL";
})(Intents = exports.Intents || (exports.Intents = {}));
// Gateway
/**
 * The possible websocket states.
 */
var Status;
(function (Status) {
    Status[Status["IDLE"] = 0] = "IDLE";
    Status[Status["READY"] = 1] = "READY";
    Status[Status["CONNECTING"] = 2] = "CONNECTING";
    Status[Status["RECONNECTING"] = 3] = "RECONNECTING";
    Status[Status["DISCONNECTED"] = 4] = "DISCONNECTED";
    Status[Status["WAITING_FOR_GUILDS"] = 5] = "WAITING_FOR_GUILDS";
    Status[Status["RESUMING"] = 6] = "RESUMING";
    Status[Status["IDENTIFYING"] = 7] = "IDENTIFYING";
})(Status = exports.Status || (exports.Status = {}));
/**
 * The possible gateway opcodes.
 */
var PacketOperation;
(function (PacketOperation) {
    PacketOperation[PacketOperation["DISPATCH"] = 0] = "DISPATCH";
    PacketOperation[PacketOperation["HEARTBEAT"] = 1] = "HEARTBEAT";
    PacketOperation[PacketOperation["IDENTIFY"] = 2] = "IDENTIFY";
    PacketOperation[PacketOperation["PRESENCE_UPDATE"] = 3] = "PRESENCE_UPDATE";
    PacketOperation[PacketOperation["VOICE_STATE_UPDATE"] = 4] = "VOICE_STATE_UPDATE";
    PacketOperation[PacketOperation["VOICE_SERVER_PING"] = 5] = "VOICE_SERVER_PING";
    PacketOperation[PacketOperation["RESUME"] = 6] = "RESUME";
    PacketOperation[PacketOperation["RECONNECT"] = 7] = "RECONNECT";
    PacketOperation[PacketOperation["REQUEST_GUILD_MEMBERS"] = 8] = "REQUEST_GUILD_MEMBERS";
    PacketOperation[PacketOperation["INVALID_SESSION"] = 9] = "INVALID_SESSION";
    PacketOperation[PacketOperation["HELLO"] = 10] = "HELLO";
    PacketOperation[PacketOperation["HEARTBEAT_ACK"] = 11] = "HEARTBEAT_ACK";
})(PacketOperation = exports.PacketOperation || (exports.PacketOperation = {}));
/**
 * The possible gateway close codes.
 */
var GatewayCloseCode;
(function (GatewayCloseCode) {
    GatewayCloseCode[GatewayCloseCode["UNKNOWN_ERROR"] = 4000] = "UNKNOWN_ERROR";
    GatewayCloseCode[GatewayCloseCode["UNKNOWN_OPCODE"] = 4001] = "UNKNOWN_OPCODE";
    GatewayCloseCode[GatewayCloseCode["DECODE_ERROR"] = 4002] = "DECODE_ERROR";
    GatewayCloseCode[GatewayCloseCode["NOT_AUTHENTICATED"] = 4003] = "NOT_AUTHENTICATED";
    GatewayCloseCode[GatewayCloseCode["AUTHENTICATION_FAILED"] = 4004] = "AUTHENTICATION_FAILED";
    GatewayCloseCode[GatewayCloseCode["ALREADY_AUTHENTICATED"] = 4005] = "ALREADY_AUTHENTICATED";
    GatewayCloseCode[GatewayCloseCode["INVALID_SEQ"] = 4007] = "INVALID_SEQ";
    GatewayCloseCode[GatewayCloseCode["RATE_LIMITED"] = 4008] = "RATE_LIMITED";
    GatewayCloseCode[GatewayCloseCode["SESSION_TIMEOUT"] = 4009] = "SESSION_TIMEOUT";
    GatewayCloseCode[GatewayCloseCode["INVALID_SHARD"] = 4010] = "INVALID_SHARD";
    GatewayCloseCode[GatewayCloseCode["SHARDING_REQUIRED"] = 4011] = "SHARDING_REQUIRED";
    GatewayCloseCode[GatewayCloseCode["INVALID_VERSION"] = 4012] = "INVALID_VERSION";
    GatewayCloseCode[GatewayCloseCode["INVALID_INTENTS"] = 4013] = "INVALID_INTENTS";
    GatewayCloseCode[GatewayCloseCode["DISALLOWED_INTENTS"] = 4014] = "DISALLOWED_INTENTS";
})(GatewayCloseCode = exports.GatewayCloseCode || (exports.GatewayCloseCode = {}));
/*
 *  Data Constants
 *  Constants for data types that the API sent
 */
// Channel
/**
 * The possible channel types.
 */
var ChannelTypes;
(function (ChannelTypes) {
    ChannelTypes[ChannelTypes["GUILD_TEXT"] = 0] = "GUILD_TEXT";
    ChannelTypes[ChannelTypes["DM"] = 1] = "DM";
    ChannelTypes[ChannelTypes["GUILD_VOICE"] = 2] = "GUILD_VOICE";
    ChannelTypes[ChannelTypes["GROUP_DM"] = 3] = "GROUP_DM";
    ChannelTypes[ChannelTypes["GUILD_CATEGORY"] = 4] = "GUILD_CATEGORY";
    ChannelTypes[ChannelTypes["GUILD_NEWS"] = 5] = "GUILD_NEWS";
    ChannelTypes[ChannelTypes["GUILD_STORE"] = 6] = "GUILD_STORE";
    ChannelTypes[ChannelTypes["GUILD_NEWS_THREAD"] = 10] = "GUILD_NEWS_THREAD";
    ChannelTypes[ChannelTypes["GUILD_PUBLIC_THREAD"] = 11] = "GUILD_PUBLIC_THREAD";
    ChannelTypes[ChannelTypes["GUILD_PRIVATE_THREAD"] = 12] = "GUILD_PRIVATE_THREAD";
    ChannelTypes[ChannelTypes["GUILD_STAGE_VOICE"] = 13] = "GUILD_STAGE_VOICE";
})(ChannelTypes = exports.ChannelTypes || (exports.ChannelTypes = {}));
/**
 * The possible system channel flags.
 */
var SystemChannelFlags;
(function (SystemChannelFlags) {
    SystemChannelFlags[SystemChannelFlags["SUPPRESS_JOIN_NOTIFICATIONS"] = 1] = "SUPPRESS_JOIN_NOTIFICATIONS";
    SystemChannelFlags[SystemChannelFlags["SUPPRESS_PREMIUM_SUBSCRIPTIONS"] = 2] = "SUPPRESS_PREMIUM_SUBSCRIPTIONS";
    SystemChannelFlags[SystemChannelFlags["SUPPRESS_GUILD_REMINDER_NOTIFICATIONS"] = 4] = "SUPPRESS_GUILD_REMINDER_NOTIFICATIONS";
    SystemChannelFlags[SystemChannelFlags["SUPPRESS_JOIN_NOTIFICATION_REPLIES"] = 8] = "SUPPRESS_JOIN_NOTIFICATION_REPLIES";
})(SystemChannelFlags = exports.SystemChannelFlags || (exports.SystemChannelFlags = {}));
// Guild
// Guild Settings Level
/**
 * The possible notification levels.
 */
var NotificationLevel;
(function (NotificationLevel) {
    NotificationLevel[NotificationLevel["ALL_MESSAGES"] = 0] = "ALL_MESSAGES";
    NotificationLevel[NotificationLevel["ONLY_MENTIONS"] = 1] = "ONLY_MENTIONS";
})(NotificationLevel = exports.NotificationLevel || (exports.NotificationLevel = {}));
/**
 * The possible verification levels.
 */
var VerificationLevel;
(function (VerificationLevel) {
    VerificationLevel[VerificationLevel["NONE"] = 0] = "NONE";
    VerificationLevel[VerificationLevel["LOW"] = 1] = "LOW";
    VerificationLevel[VerificationLevel["MEDIUM"] = 2] = "MEDIUM";
    VerificationLevel[VerificationLevel["HIGH"] = 3] = "HIGH";
    VerificationLevel[VerificationLevel["VERY_HIGH"] = 4] = "VERY_HIGH";
})(VerificationLevel = exports.VerificationLevel || (exports.VerificationLevel = {}));
/**
 * The possible MFA requirement levels.
 */
var MFALevel;
(function (MFALevel) {
    MFALevel[MFALevel["NONE"] = 0] = "NONE";
    MFALevel[MFALevel["ELEVATED"] = 1] = "ELEVATED";
})(MFALevel = exports.MFALevel || (exports.MFALevel = {}));
/**
 * The possible explicit content filter levels.
 */
var ExplicitContentFilterLevel;
(function (ExplicitContentFilterLevel) {
    ExplicitContentFilterLevel[ExplicitContentFilterLevel["DISABLED"] = 0] = "DISABLED";
    ExplicitContentFilterLevel[ExplicitContentFilterLevel["MEMBERS_WITHOUT_ROLES"] = 1] = "MEMBERS_WITHOUT_ROLES";
    ExplicitContentFilterLevel[ExplicitContentFilterLevel["ALL_MEMBERS"] = 2] = "ALL_MEMBERS";
})(ExplicitContentFilterLevel = exports.ExplicitContentFilterLevel || (exports.ExplicitContentFilterLevel = {}));
/**
 * The possible NSFW levels.
 */
var NSFWLevel;
(function (NSFWLevel) {
    NSFWLevel[NSFWLevel["UNKNOWN"] = 0] = "UNKNOWN";
    NSFWLevel[NSFWLevel["EXPLICIT"] = 1] = "EXPLICIT";
    NSFWLevel[NSFWLevel["SAFE"] = 2] = "SAFE";
    NSFWLevel[NSFWLevel["AGE_RESTRICTED"] = 3] = "AGE_RESTRICTED";
})(NSFWLevel = exports.NSFWLevel || (exports.NSFWLevel = {}));
// Guild Boost Level
/**
 * The possible guild boost levels.
 */
var PremiumTier;
(function (PremiumTier) {
    PremiumTier[PremiumTier["NONE"] = 0] = "NONE";
    PremiumTier[PremiumTier["TIER_1"] = 1] = "TIER_1";
    PremiumTier[PremiumTier["TIER_2"] = 2] = "TIER_2";
    PremiumTier[PremiumTier["TIER_3"] = 3] = "TIER_3";
})(PremiumTier = exports.PremiumTier || (exports.PremiumTier = {}));
// Guild Events
/**
 * The possible guild event privacy levels.
 */
var GuildScheduledEventsPrivacyLevel;
(function (GuildScheduledEventsPrivacyLevel) {
    GuildScheduledEventsPrivacyLevel[GuildScheduledEventsPrivacyLevel["GUILD_ONLY"] = 2] = "GUILD_ONLY";
})(GuildScheduledEventsPrivacyLevel = exports.GuildScheduledEventsPrivacyLevel || (exports.GuildScheduledEventsPrivacyLevel = {}));
/**
 * The possible guild event entity types.
 */
var GuildScheduledEventsEntityTypes;
(function (GuildScheduledEventsEntityTypes) {
    GuildScheduledEventsEntityTypes[GuildScheduledEventsEntityTypes["STAGE_INSTANCE"] = 1] = "STAGE_INSTANCE";
    GuildScheduledEventsEntityTypes[GuildScheduledEventsEntityTypes["VOICE"] = 2] = "VOICE";
    GuildScheduledEventsEntityTypes[GuildScheduledEventsEntityTypes["EXTERNAL"] = 3] = "EXTERNAL";
})(GuildScheduledEventsEntityTypes = exports.GuildScheduledEventsEntityTypes || (exports.GuildScheduledEventsEntityTypes = {}));
// Guild Invite
/**
 * The possible invite types.
 */
var InviteTargetTypes;
(function (InviteTargetTypes) {
    InviteTargetTypes[InviteTargetTypes["STREAM"] = 1] = "STREAM";
    InviteTargetTypes[InviteTargetTypes["EMBEDDED_APPLICATION"] = 2] = "EMBEDDED_APPLICATION";
})(InviteTargetTypes = exports.InviteTargetTypes || (exports.InviteTargetTypes = {}));
// Guild Stage
/**
 * The possible stage privacy levels.
 */
var StageInstancePrivacyLevel;
(function (StageInstancePrivacyLevel) {
    StageInstancePrivacyLevel[StageInstancePrivacyLevel["PUBLIC"] = 1] = "PUBLIC";
    StageInstancePrivacyLevel[StageInstancePrivacyLevel["GUILD_ONLY"] = 2] = "GUILD_ONLY";
})(StageInstancePrivacyLevel = exports.StageInstancePrivacyLevel || (exports.StageInstancePrivacyLevel = {}));
// Presence
/**
 * The possible activity types.
 */
var ActivityType;
(function (ActivityType) {
    ActivityType[ActivityType["PLAYING"] = 0] = "PLAYING";
    ActivityType[ActivityType["STREAMING"] = 1] = "STREAMING";
    ActivityType[ActivityType["LISTENING"] = 2] = "LISTENING";
    ActivityType[ActivityType["WATCHING"] = 3] = "WATCHING";
    ActivityType[ActivityType["CUSTOM"] = 4] = "CUSTOM";
    ActivityType[ActivityType["COMPETING"] = 5] = "COMPETING";
})(ActivityType = exports.ActivityType || (exports.ActivityType = {}));
// Message
/**
 * The possible message types.
 */
var MessageTypes;
(function (MessageTypes) {
    MessageTypes[MessageTypes["DEFAULT"] = 0] = "DEFAULT";
    MessageTypes[MessageTypes["RECIPIENT_ADD"] = 1] = "RECIPIENT_ADD";
    MessageTypes[MessageTypes["RECIPIENT_REMOVE"] = 2] = "RECIPIENT_REMOVE";
    MessageTypes[MessageTypes["CALL"] = 3] = "CALL";
    MessageTypes[MessageTypes["CHANNEL_NAME_CHANGE"] = 4] = "CHANNEL_NAME_CHANGE";
    MessageTypes[MessageTypes["CHANNEL_ICON_CHANGE"] = 5] = "CHANNEL_ICON_CHANGE";
    MessageTypes[MessageTypes["CHANNEL_PINNED_MESSAGE"] = 6] = "CHANNEL_PINNED_MESSAGE";
    MessageTypes[MessageTypes["GUILD_MEMBER_JOIN"] = 7] = "GUILD_MEMBER_JOIN";
    MessageTypes[MessageTypes["USER_PREMIUM_GUILD_SUBSCRIPTION"] = 8] = "USER_PREMIUM_GUILD_SUBSCRIPTION";
    MessageTypes[MessageTypes["USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_1"] = 9] = "USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_1";
    MessageTypes[MessageTypes["USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_2"] = 10] = "USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_2";
    MessageTypes[MessageTypes["USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_3"] = 11] = "USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_3";
    MessageTypes[MessageTypes["CHANNEL_FOLLOW_ADD"] = 12] = "CHANNEL_FOLLOW_ADD";
    MessageTypes[MessageTypes["GUILD_DISCOVERY_DISQUALIFIED"] = 14] = "GUILD_DISCOVERY_DISQUALIFIED";
    MessageTypes[MessageTypes["GUILD_DISCOVERY_REQUALIFIED"] = 15] = "GUILD_DISCOVERY_REQUALIFIED";
    MessageTypes[MessageTypes["GUILD_DISCOVERY_GRACE_PERIOD_INITIAL_WARNING"] = 16] = "GUILD_DISCOVERY_GRACE_PERIOD_INITIAL_WARNING";
    MessageTypes[MessageTypes["GUILD_DISCOVERY_GRACE_PERIOD_FINAL_WARNING"] = 17] = "GUILD_DISCOVERY_GRACE_PERIOD_FINAL_WARNING";
    MessageTypes[MessageTypes["THREAD_CREATED"] = 18] = "THREAD_CREATED";
    MessageTypes[MessageTypes["REPLY"] = 19] = "REPLY";
    MessageTypes[MessageTypes["CHAT_INPUT_COMMAND"] = 20] = "CHAT_INPUT_COMMAND";
    MessageTypes[MessageTypes["THREAD_STARTER_MESSAGE"] = 21] = "THREAD_STARTER_MESSAGE";
    MessageTypes[MessageTypes["GUILD_INVITE_REMINDER"] = 22] = "GUILD_INVITE_REMINDER";
    MessageTypes[MessageTypes["CONTEXT_MENU_COMMAND"] = 23] = "CONTEXT_MENU_COMMAND";
})(MessageTypes = exports.MessageTypes || (exports.MessageTypes = {}));
/**
 * The possible system message types.
 */
var SystemMessageTypes;
(function (SystemMessageTypes) {
    SystemMessageTypes[SystemMessageTypes["RECIPIENT_ADD"] = 1] = "RECIPIENT_ADD";
    SystemMessageTypes[SystemMessageTypes["RECIPIENT_REMOVE"] = 2] = "RECIPIENT_REMOVE";
    SystemMessageTypes[SystemMessageTypes["CALL"] = 3] = "CALL";
    SystemMessageTypes[SystemMessageTypes["CHANNEL_NAME_CHANGE"] = 4] = "CHANNEL_NAME_CHANGE";
    SystemMessageTypes[SystemMessageTypes["CHANNEL_ICON_CHANGE"] = 5] = "CHANNEL_ICON_CHANGE";
    SystemMessageTypes[SystemMessageTypes["CHANNEL_PINNED_MESSAGE"] = 6] = "CHANNEL_PINNED_MESSAGE";
    SystemMessageTypes[SystemMessageTypes["GUILD_MEMBER_JOIN"] = 7] = "GUILD_MEMBER_JOIN";
    SystemMessageTypes[SystemMessageTypes["USER_PREMIUM_GUILD_SUBSCRIPTION"] = 8] = "USER_PREMIUM_GUILD_SUBSCRIPTION";
    SystemMessageTypes[SystemMessageTypes["USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_1"] = 9] = "USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_1";
    SystemMessageTypes[SystemMessageTypes["USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_2"] = 10] = "USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_2";
    SystemMessageTypes[SystemMessageTypes["USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_3"] = 11] = "USER_PREMIUM_GUILD_SUBSCRIPTION_TIER_3";
    SystemMessageTypes[SystemMessageTypes["CHANNEL_FOLLOW_ADD"] = 12] = "CHANNEL_FOLLOW_ADD";
    SystemMessageTypes[SystemMessageTypes["GUILD_DISCOVERY_DISQUALIFIED"] = 14] = "GUILD_DISCOVERY_DISQUALIFIED";
    SystemMessageTypes[SystemMessageTypes["GUILD_DISCOVERY_REQUALIFIED"] = 15] = "GUILD_DISCOVERY_REQUALIFIED";
    SystemMessageTypes[SystemMessageTypes["GUILD_DISCOVERY_GRACE_PERIOD_INITIAL_WARNING"] = 16] = "GUILD_DISCOVERY_GRACE_PERIOD_INITIAL_WARNING";
    SystemMessageTypes[SystemMessageTypes["GUILD_DISCOVERY_GRACE_PERIOD_FINAL_WARNING"] = 17] = "GUILD_DISCOVERY_GRACE_PERIOD_FINAL_WARNING";
    SystemMessageTypes[SystemMessageTypes["THREAD_CREATED"] = 18] = "THREAD_CREATED";
    SystemMessageTypes[SystemMessageTypes["THREAD_STARTER_MESSAGE"] = 21] = "THREAD_STARTER_MESSAGE";
    SystemMessageTypes[SystemMessageTypes["GUILD_INVITE_REMINDER"] = 22] = "GUILD_INVITE_REMINDER";
})(SystemMessageTypes = exports.SystemMessageTypes || (exports.SystemMessageTypes = {}));
/**
 * The possible message flags.
 */
var MessageFlags;
(function (MessageFlags) {
    MessageFlags[MessageFlags["CROSSPOSTED"] = 1] = "CROSSPOSTED";
    MessageFlags[MessageFlags["IS_CROSSPOST"] = 2] = "IS_CROSSPOST";
    MessageFlags[MessageFlags["SUPPRESS_EMBEDS"] = 4] = "SUPPRESS_EMBEDS";
    MessageFlags[MessageFlags["SOURCE_MESSAGE_DELETED"] = 8] = "SOURCE_MESSAGE_DELETED";
    MessageFlags[MessageFlags["URGENT"] = 16] = "URGENT";
    MessageFlags[MessageFlags["HAS_THREAD"] = 32] = "HAS_THREAD";
    MessageFlags[MessageFlags["EPHEMERAL"] = 64] = "EPHEMERAL";
    MessageFlags[MessageFlags["LOADING"] = 128] = "LOADING";
})(MessageFlags = exports.MessageFlags || (exports.MessageFlags = {}));
// Sticker
/**
 * The possible sticker types.
 */
var StickerTypes;
(function (StickerTypes) {
    StickerTypes[StickerTypes["STANDARD"] = 1] = "STANDARD";
    StickerTypes[StickerTypes["GUILD"] = 2] = "GUILD";
})(StickerTypes = exports.StickerTypes || (exports.StickerTypes = {}));
/**
 * The possible sticker formats.
 */
var StickerFormatTypes;
(function (StickerFormatTypes) {
    StickerFormatTypes[StickerFormatTypes["PNG"] = 1] = "PNG";
    StickerFormatTypes[StickerFormatTypes["APNG"] = 2] = "APNG";
    StickerFormatTypes[StickerFormatTypes["LOTTIE"] = 3] = "LOTTIE";
})(StickerFormatTypes = exports.StickerFormatTypes || (exports.StickerFormatTypes = {}));
// User
/**
 * The possible user flags.
 */
var UserFlags;
(function (UserFlags) {
    UserFlags[UserFlags["None"] = 0] = "None";
    UserFlags[UserFlags["DISCORD_EMPLOYEE"] = 1] = "DISCORD_EMPLOYEE";
    UserFlags[UserFlags["PARTNER"] = 2] = "PARTNER";
    UserFlags[UserFlags["HYPESQUAD"] = 4] = "HYPESQUAD";
    UserFlags[UserFlags["BUG_HUNTER_LEVEL_1"] = 8] = "BUG_HUNTER_LEVEL_1";
    UserFlags[UserFlags["HYPESQUAD_ONLINE_HOUSE_1"] = 64] = "HYPESQUAD_ONLINE_HOUSE_1";
    UserFlags[UserFlags["HYPESQUAD_ONLINE_HOUSE_2"] = 128] = "HYPESQUAD_ONLINE_HOUSE_2";
    UserFlags[UserFlags["HYPESQUAD_ONLINE_HOUSE_3"] = 256] = "HYPESQUAD_ONLINE_HOUSE_3";
    UserFlags[UserFlags["PREMIUM_EARLY_SUPPORTER"] = 512] = "PREMIUM_EARLY_SUPPORTER";
    UserFlags[UserFlags["TEAM_PSEUDO_USER"] = 1024] = "TEAM_PSEUDO_USER";
    UserFlags[UserFlags["BUG_HUNTER_LEVEL_2"] = 16384] = "BUG_HUNTER_LEVEL_2";
    UserFlags[UserFlags["VERIFIED_BOT"] = 65536] = "VERIFIED_BOT";
    UserFlags[UserFlags["VERIFIED_DEVELOPER"] = 131072] = "VERIFIED_DEVELOPER";
    UserFlags[UserFlags["CERTIFIED_MODERATOR"] = 262144] = "CERTIFIED_MODERATOR";
    UserFlags[UserFlags["BOT_HTTP_INTERACTIONS"] = 524288] = "BOT_HTTP_INTERACTIONS";
})(UserFlags = exports.UserFlags || (exports.UserFlags = {}));
/**
 * The possible user visibility types.
 */
var VisibilityTypes;
(function (VisibilityTypes) {
    VisibilityTypes[VisibilityTypes["NONE"] = 0] = "NONE";
    VisibilityTypes[VisibilityTypes["EVERYONE"] = 1] = "EVERYONE";
})(VisibilityTypes = exports.VisibilityTypes || (exports.VisibilityTypes = {}));
// Webhook
/**
 * The possible webhook types.
 */
var WebhookTypes;
(function (WebhookTypes) {
    WebhookTypes[WebhookTypes["INCOMING"] = 1] = "INCOMING";
    WebhookTypes[WebhookTypes["CHANNEL_FOLLOWER"] = 2] = "CHANNEL_FOLLOWER";
    WebhookTypes[WebhookTypes["APPLICATION"] = 3] = "APPLICATION";
})(WebhookTypes = exports.WebhookTypes || (exports.WebhookTypes = {}));
